==> rtdip-sdk-0.7.10.tar.gz: rtdip-sdk-0.7.10/src/sdk/python/rtdip_sdk/pipelines/_pipeline_utils/obc_field_mappings.py <==
# Copyright 2022 RTDIP
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

OBC_FIELD_MAPPINGS_V10 = {
    "0": {"TagName": "obc_timeStamp", "ValueType": "double"},
    "1": {"TagName": "obc_errorState", "ValueType": "integer"},
    "2": {"TagName": "obc_energyThreshold", "ValueType": "float"},
    "3": {"TagName": "obc_energyLevel", "ValueType": "float"},
    "4": {"TagName": "gps_errorState", "ValueType": "integer"},
    "5": {"TagName": "gps_utcTime", "ValueType": "string"},
    "6": {"TagName": "gps_latitude", "ValueType": "double"},
    "7": {"TagName": "gps_longitude", "ValueType": "double"},
    "8": {"TagName": "gps_fixQuality", "ValueType": "integer"},
    "9": {"TagName": "gps_dilution", "ValueType": "float"},
    "10": {"TagName": "gps_speed", "ValueType": "float"},
    "11": {"TagName": "jm_errorState", "ValueType": "integer"},
    "12": {"TagName": "jm_posJoule", "ValueType": "integer"},
    "13": {"TagName": "jm_negJoule", "ValueType": "integer"},
    "14": {"TagName": "jm_netJoule", "ValueType": "integer"},
    "15": {"TagName": "jm_globalTime", "ValueType": "string"},
    "16": {"TagName": "jm_voltage", "ValueType": "integer"},
    "17": {"TagName": "jm_current", "ValueType": "integer"},
    "18": {"TagName": "jm_battVolt", "ValueType": "float"},
    "19": {"TagName": "lfm_errorState", "ValueType": "integer"},
    "20": {"TagName": "lfm_msSinceReset", "ValueType": "integer"},
    "21": {"TagName": "lfm_temperature", "ValueType": "float"},
    "22": {"TagName": "lfm_integratedCorrFlow", "ValueType": "float"},
    "23": {"TagName": "lfm_instantFlow", "ValueType": "float"},
    "24": {"TagName": "gfs_errorState", "ValueType": "integer"},
    "25": {"TagName": "gfs_gasFlow", "ValueType": "float"},
    "26": {"TagName": "gfs_gasTemp", "ValueType": "float"},
    "27": {"TagName": "gfs_netGasVolume", "ValueType": "float"},
    "28": {"TagName": "do_errorState", "ValueType": "integer"},
    "29": {"TagName": "do_state", "ValueType": "integer"},
    "30": {"TagName": "jm3_errorState", "ValueType": "integer"},
    "31": {"TagName": "jm3_ms_since_reset", "ValueType": "integer"},
    "32": {"TagName": "jm3_netjoule", "ValueType": "integer"},
    "33": {"TagName": "jm3_voltage", "ValueType": "integer"},
    "34": {"TagName": "jm3_current", "ValueType": "integer"},
    "35": {"TagName": "sup_errorState", "ValueType": "integer"},
    "36": {"TagName": "sup_VoltageIn", "ValueType": "integer"},
    "37": {"TagName": "all_msSinceReset", "ValueType": "integer"},
    "38": {"TagName": "iot_errorState", "ValueType": "integer"},
    "39": {"TagName": "iot_route", "ValueType": "text"},
    "40": {"TagName": "cell_mode", "ValueType": "text"},
    "41": {"TagName": "cell_rssi", "ValueType": "integer"},
    "42": {"TagName": "wifi_power", "ValueType": "integer"},
    "43": {"TagName": "message_id", "ValueType": "string"},
    "44": {"TagName": "volt_errorState", "ValueType": "integer"},
    "45": {"TagName": "volt_ms_since_reset", "ValueType": "integer"},
    "46": {"TagName": "volt_voltage", "ValueType": "integer"},
    "47": {"TagName": "volt_difference", "ValueType": "integer"},
    "48": {"TagName": "sb_errorState", "ValueType": "integer"},
    "49": {"TagName": "sb_isAutonomous", "ValueType": "integer"},
}

==> rtdip-sdk-0.9.9.tar.gz: rtdip-sdk-0.9.9/src/sdk/python/rtdip_sdk/pipelines/_pipeline_utils/obc_field_mappings.py <==
# Copyright 2022 RTDIP
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

OBC_FIELD_MAPPINGS_V10 = {
    "0": {"TagName": "obc_timeStamp", "ValueType": "float"},
    "1": {"TagName": "obc_errorState", "ValueType": "integer"},
    "2": {"TagName": "obc_energyThreshold", "ValueType": "float"},
    "3": {"TagName": "obc_energyLevel", "ValueType": "float"},
    "4": {"TagName": "gps_errorState", "ValueType": "integer"},
    "5": {"TagName": "gps_utcTime", "ValueType": "string"},
    "6": {"TagName": "gps_latitude", "ValueType": "float"},
    "7": {"TagName": "gps_longitude", "ValueType": "float"},
    "8": {"TagName": "gps_fixQuality", "ValueType": "integer"},
    "9": {"TagName": "gps_dilution", "ValueType": "float"},
    "10": {"TagName": "gps_speed", "ValueType": "float"},
    "11": {"TagName": "jm_errorState", "ValueType": "integer"},
    "12": {"TagName": "jm_posJoule", "ValueType": "integer"},
    "13": {"TagName": "jm_negJoule", "ValueType": "integer"},
    "14": {"TagName": "jm_netJoule", "ValueType": "integer"},
    "15": {"TagName": "jm_globalTime", "ValueType": "string"},
    "16": {"TagName": "jm_voltage", "ValueType": "integer"},
    "17": {"TagName": "jm_current", "ValueType": "integer"},
    "18": {"TagName": "jm_battVolt", "ValueType": "float"},
    "19": {"TagName": "lfm_errorState", "ValueType": "integer"},
    "20": {"TagName": "lfm_msSinceReset", "ValueType": "integer"},
    "21": {"TagName": "lfm_temperature", "ValueType": "float"},
    "22": {"TagName": "lfm_integratedCorrFlow", "ValueType": "float"},
    "23": {"TagName": "lfm_instantFlow", "ValueType": "float"},
    "24": {"TagName": "gfs_errorState", "ValueType": "integer"},
    "25": {"TagName": "gfs_gasFlow", "ValueType": "float"},
    "26": {"TagName": "gfs_gasTemp", "ValueType": "float"},
    "27": {"TagName": "gfs_netGasVolume", "ValueType": "float"},
    "28": {"TagName": "do_errorState", "ValueType": "integer"},
    "29": {"TagName": "do_state", "ValueType": "integer"},
    "30": {"TagName": "jm3_errorState", "ValueType": "integer"},
    "31": {"TagName": "jm3_ms_since_reset", "ValueType": "integer"},
    "32": {"TagName": "jm3_netjoule", "ValueType": "integer"},
    "33": {"TagName": "jm3_voltage", "ValueType": "integer"},
    "34": {"TagName": "jm3_current", "ValueType": "integer"},
    "35": {"TagName": "sup_errorState", "ValueType": "integer"},
    "36": {"TagName": "sup_VoltageIn", "ValueType": "integer"},
    "37": {"TagName": "all_msSinceReset", "ValueType": "integer"},
    "38": {"TagName": "iot_errorState", "ValueType": "integer"},
    "39": {"TagName": "iot_route", "ValueType": "integer"},
    "40": {"TagName": "cell_mode", "ValueType": "string"},
    "41": {"TagName": "cell_rssi", "ValueType": "integer"},
    "42": {"TagName": "wifi_power", "ValueType": "integer"},
    "43": {"TagName": "message_id", "ValueType": "string"},
    "44": {"TagName": "volt_errorState", "ValueType": "integer"},
    "45": {"TagName": "volt_ms_since_reset", "ValueType": "integer"},
    "46": {"TagName": "volt_voltage", "ValueType": "integer"},
    "47": {"TagName": "volt_difference", "ValueType": "integer"},
    "48": {"TagName": "sb_errorState", "ValueType": "integer"},
    "49": {"TagName": "sb_isAutonomous", "ValueType": "integer"},
}
